@@ -309,38 +309,50 @@ def similarity(word1: str, word2: str, *, allow_sentence: bool = False, style: s
     else:
         return style % (point * 100)
 
-
-@lru_cache(maxsize=1)
-def _cached_words(source=None, filter=True):
-    return tuple(words(source=source, filter=filter))
-
-
-def accuracy_per_word(
-    word: str,
-    *,
-    sort: bool = False,
-    allow_sentence: bool = False,
-    style: str = None,
-    source: str = None,
-    filter: bool = True
-) -> Union[str, float]:
-    """
-    a function that gives you all accuracy per words
-    """
-    all_words = _cached_words(source=source, filter=filter)
-
-    scored = [(similarity(word, w, allow_sentence=allow_sentence), w) for w in all_words]
-
-    if sort:
-        scored.sort(key=lambda x: x[0], reverse=True)
-
-    if style is not None:
-        return style % (scored[0][0] * 100)
-    else:
-        return scored[0][0]
-
 def fix_spelling(word: str, words_list: list) -> str:
     """
     a function that fixes spelling
     """
-    return max(words_list, key=lambda w: similarity(word, w, allow_sentence=True))
\ No newline at end of file
+    return max(words_list, key=lambda w: similarity(word, w, allow_sentence=True))
+
+def normalize(char: str) -> str:
+    """
+    normalizes (breaks down) the compounds, complexes, ancients, parts
+    """
+    korean_normalization = {
+        "ㄲ": "ㄱㄱ",
+        "ㄳ": "ㄱㅅ",
+        "ㄵ": "ㄴㅈ",
+        "ㄶ": "ㄴㅎ",
+        "ㄺ": "ㄹㄱ",
+        "ㄻ": "ㄹㅁ",
+        "ㄼ": "ㄹㅂ",
+        "ㄽ": "ㄹㅅ",
+        "ㄾ": "ㄹㅌ",
+        "ㄿ": "ㄹㅍ",
+        "ㅀ": "ㄹㅎ",
+        "ㅄ": "ㅂㅅ",
+        "ㅆ": "ㅅㅅ",
+        "ㅘ": "ㅗㅏ",
+        "ㅙ": "ㅗㅐ",
+        "ㅚ": "ㅗㅣ",
+        "ㅝ": "ㅜㅓ",
+        "ㅞ": "ㅜㅔ",
+        "ㅟ": "ㅜㅣ",
+        "ㅢ": "ㅡㅣ",
+        "ㅿ": "ㅅ",
+        "ㆁ": "ㅇ",
+        "ㆆ": "ㅎ", 
+        "ᄛ": "ㅅㅅ", 
+        "ᄣ": "ㅅㅎ", 
+        "ᄦ": "ㅂㅅㅈ", 
+        "ᅇ": "ㅎ",   
+        "ᅌ": "ㅇ",   
+        "ᅎ": "ㅈㅎ",
+        "ㆍ": "ㅏ",
+        "ㆎ": "ㅐ",
+        "ᆢ": "ㅡㅡ"
+    }
+    for raw, new in korean_normalization:
+        if char == raw:
+            return new
\ No newline at end of file
